@@ -93,7 +93,6 @@ from pytensor.tensor.var import TensorVariable
 from pymc.logprob.abstract import (
     MeasurableElemwise,
     MeasurableVariable,
-    _get_measurable_outputs,
     _icdf,
     _icdf_helper,
     _logcdf,
@@ -106,7 +105,7 @@ from pymc.logprob.rewriting import (
     cleanup_ir_rewrites_db,
     measurable_ir_rewrites_db,
 )
-from pymc.logprob.utils import check_potential_measurability, ignore_logprob
+from pymc.logprob.utils import check_potential_measurability
 
 
 class TransformedVariable(Op):
@@ -224,7 +223,6 @@ def transform_values(fgraph: FunctionGraph, node: Node) -> Optional[List[Node]]:
     # with "inversely/un-" transformed versions of itself.
     for rv_var, value_var, transform in zip(rv_vars, value_vars, transforms):
         rv_var_out_idx = node.outputs.index(rv_var)
-        trans_node.outputs[rv_var_out_idx].name = rv_var.name
 
         if transform is None:
             continue
@@ -288,7 +286,6 @@ def transform_scan_values(fgraph: FunctionGraph, node: Node) -> Optional[List[No
     # with "inversely/un-" transformed versions of itself.
     for rv_var, value_var, transform in zip(rv_vars, value_vars, transforms):
         rv_var_out_idx = node.outputs.index(rv_var)
-        trans_node.outputs[rv_var_out_idx].name = rv_var.name
 
         if transform is None:
             continue
@@ -385,11 +382,6 @@ class MeasurableTransform(MeasurableElemwise):
         super().__init__(*args, **kwargs)
 
 
-@_get_measurable_outputs.register(MeasurableTransform)
-def _get_measurable_outputs_Transform(op, node):
-    return [node.default_output()]
-
-
 @_logprob.register(MeasurableTransform)
 def measurable_transform_logprob(op: MeasurableTransform, values, *inputs, **kwargs):
     """Compute the log-probability graph for a `MeasurabeTransform`."""
@@ -461,36 +453,14 @@ def measurable_transform_icdf(op: MeasurableTransform, value, *inputs, **kwargs)
 @node_rewriter([reciprocal])
 def measurable_reciprocal_to_power(fgraph, node):
     """Convert reciprocal of `MeasurableVariable`s to power."""
-    inp = node.inputs[0]
-    if not (inp.owner and isinstance(inp.owner.op, MeasurableVariable)):
-        return None
-
-    rv_map_feature: Optional[PreserveRVMappings] = getattr(fgraph, "preserve_rv_mappings", None)
-    if rv_map_feature is None:
-        return None  # pragma: no cover
-
-    # Only apply this rewrite if the variable is unvalued
-    if inp in rv_map_feature.rv_values:
-        return None  # pragma: no cover
-
+    [inp] = node.inputs
     return [pt.pow(inp, -1.0)]
 
 
 @node_rewriter([sqr, sqrt])
 def measurable_sqrt_sqr_to_power(fgraph, node):
     """Convert square root or square of `MeasurableVariable`s to power form."""
-
-    inp = node.inputs[0]
-    if not (inp.owner and isinstance(inp.owner.op, MeasurableVariable)):
-        return None
-
-    rv_map_feature: Optional[PreserveRVMappings] = getattr(fgraph, "preserve_rv_mappings", None)
-    if rv_map_feature is None:
-        return None  # pragma: no cover
-
-    # Only apply this rewrite if the variable is unvalued
-    if inp in rv_map_feature.rv_values:
-        return None  # pragma: no cover
+    [inp] = node.inputs
 
     if isinstance(node.op.scalar_op, Sqr):
         return [pt.pow(inp, 2)]
@@ -502,21 +472,6 @@ def measurable_sqrt_sqr_to_power(fgraph, node):
 @node_rewriter([true_div])
 def measurable_div_to_product(fgraph, node):
     """Convert divisions involving `MeasurableVariable`s to products."""
-
-    measurable_vars = [
-        var for var in node.inputs if (var.owner and isinstance(var.owner.op, MeasurableVariable))
-    ]
-    if not measurable_vars:
-        return None  # pragma: no cover
-
-    rv_map_feature: Optional[PreserveRVMappings] = getattr(fgraph, "preserve_rv_mappings", None)
-    if rv_map_feature is None:
-        return None  # pragma: no cover
-
-    # Only apply this rewrite if there is one unvalued MeasurableVariable involved
-    if all(measurable_var in rv_map_feature.rv_values for measurable_var in measurable_vars):
-        return None  # pragma: no cover
-
     numerator, denominator = node.inputs
 
     # Check if numerator is 1
@@ -535,39 +490,13 @@ def measurable_div_to_product(fgraph, node):
 @node_rewriter([neg])
 def measurable_neg_to_product(fgraph, node):
     """Convert negation of `MeasurableVariable`s to product with `-1`."""
-
     inp = node.inputs[0]
-    if not (inp.owner and isinstance(inp.owner.op, MeasurableVariable)):
-        return None
-
-    rv_map_feature: Optional[PreserveRVMappings] = getattr(fgraph, "preserve_rv_mappings", None)
-    if rv_map_feature is None:
-        return None  # pragma: no cover
-
-    # Only apply this rewrite if the variable is unvalued
-    if inp in rv_map_feature.rv_values:
-        return None  # pragma: no cover
-
     return [pt.mul(inp, -1.0)]
 
 
 @node_rewriter([sub])
 def measurable_sub_to_neg(fgraph, node):
     """Convert subtraction involving `MeasurableVariable`s to addition with neg"""
-    measurable_vars = [
-        var for var in node.inputs if (var.owner and isinstance(var.owner.op, MeasurableVariable))
-    ]
-    if not measurable_vars:
-        return None  # pragma: no cover
-
-    rv_map_feature: Optional[PreserveRVMappings] = getattr(fgraph, "preserve_rv_mappings", None)
-    if rv_map_feature is None:
-        return None  # pragma: no cover
-
-    # Only apply this rewrite if there is one unvalued MeasurableVariable involved
-    if all(measurable_var in rv_map_feature.rv_values for measurable_var in measurable_vars):
-        return None  # pragma: no cover
-
     minuend, subtrahend = node.inputs
     return [pt.add(minuend, pt.neg(subtrahend))]
 
@@ -585,18 +514,12 @@ def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[Li
         return None  # pragma: no cover
 
     # Check that we have a single source of measurement
-    measurable_inputs = [
-        inp
-        for idx, inp in enumerate(node.inputs)
-        if inp.owner
-        and isinstance(inp.owner.op, MeasurableVariable)
-        and inp not in rv_map_feature.rv_values
-    ]
+    measurable_inputs = rv_map_feature.request_measurable(node.inputs)
 
     if len(measurable_inputs) != 1:
         return None
 
-    measurable_input: TensorVariable = measurable_inputs[0]
+    [measurable_input] = measurable_inputs
 
     # Do not apply rewrite to discrete variables
     if measurable_input.type.dtype.startswith("int"):
@@ -606,13 +529,9 @@ def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[Li
     # would be invalid
     other_inputs = tuple(inp for inp in node.inputs if inp is not measurable_input)
 
-    if not check_potential_measurability(other_inputs, rv_map_feature):
+    if check_potential_measurability(other_inputs, rv_map_feature.rv_values.keys()):
         return None
 
-    # Make base_measure outputs unmeasurable
-    # This seems to be the only thing preventing nested rewrites from being erased
-    measurable_input = ignore_logprob(measurable_input)
-
     scalar_op = node.op.scalar_op
     measurable_input_idx = 0
     transform_inputs: Tuple[TensorVariable, ...] = (measurable_input,)
@@ -659,8 +578,6 @@ def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[Li
         measurable_input_idx=measurable_input_idx,
     )
     transform_out = transform_op.make_node(*transform_inputs).default_output()
-    transform_out.name = node.outputs[0].name
-
     return [transform_out]
 
 
