@@ -65,6 +65,7 @@ from pytensor.tensor.var import TensorConstant, TensorVariable
 from pymc.exceptions import NotConstantValueError
 from pymc.logprob.transforms import RVTransform
 from pymc.logprob.utils import CheckParameterValue
+from pymc.util import makeiter
 from pymc.vartypes import continuous_types, isgenerator, typefilter
 
 PotentialShapeType = Union[int, np.ndarray, Sequence[Union[int, Variable]], TensorVariable]
@@ -550,13 +551,6 @@ def hessian_diag(f, vars=None):
         return empty_gradient
 
 
-def makeiter(a):
-    if isinstance(a, (tuple, list)):
-        return a
-    else:
-        return [a]
-
-
 class IdentityOp(scalar.UnaryScalarOp):
     @staticmethod
     def st_impl(x):
